Changelog for Saruman
=====================

0.2.0 (2016-01-03)
------------------

- adding sphinx documentation
- adding CI coverage
- fixing nasty unpack in modprobe.py


0.1.2 (2016-01-03)
------------------

- fixing some typo.


0.1.1 (2016-01-03)
------------------

- remove download urls as we use sdist


0.1.0 (2016-01-03)
------------------

- add zest.release to perform check on release an better automation
- add some yaml config files
